pub struct StoredBlockAccessListKey { /* private fields */ }Expand description
Block access list table key.
Encoded as block number followed by block hash so pruning can scan by block number.
Implementations
Sourceimpl StoredBlockAccessListKey
impl StoredBlockAccessListKey
Sourcepub const fn new(block_number: BlockNumber, block_hash: B256) -> Self
pub const fn new(block_number: BlockNumber, block_hash: B256) -> Self
Creates a key from a block number/hash pair.
Sourcepub const fn first_at_number(block_number: BlockNumber) -> Self
pub const fn first_at_number(block_number: BlockNumber) -> Self
Returns the smallest key for the given block number.