DupSort

Trait DupSort 

pub trait DupSort: Table {
    type SubKey: Key;
}
DupSort allows for keys to be repeated in the database.

Upstream docs: https://libmdbx.dqdkfa.ru/usage.html#autotoc_md48

Required Associated Types

type SubKey: Key

The table subkey. This type must implement Encode and Decode.

Sorting should be taken into account when encoding this.

Upstream docs: https://libmdbx.dqdkfa.ru/usage.html#autotoc_md48

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl DupSort for AccountChangeSets

Source

type SubKey = Address

Source

impl DupSort for HashedStorages

Source

type SubKey = FixedBytes<32>

Source

impl DupSort for PackedStoragesTrie

Source

type SubKey = PackedStoredNibblesSubKey

Source

impl DupSort for PlainStorageState

Source

type SubKey = FixedBytes<32>

Source

impl DupSort for StorageChangeSets

Source

type SubKey = FixedBytes<32>

Source

impl DupSort for StoragesTrie

Source

type SubKey = StoredNibblesSubKey

Source

impl<T: DupSort> DupSort for RawDupSort<T>