TableImporter

Trait TableImporter 

pub trait TableImporter: DbTxMut {
    // Provided methods
    fn import_table<T: Table, R: DbTx>(
        &self,
        source_tx: &R,
    ) -> Result<(), DatabaseError> { ... }
    fn import_table_with_range<T: Table, R: DbTx>(
        &self,
        source_tx: &R,
        from: Option<<T as Table>::Key>,
        to: <T as Table>::Key,
    ) -> Result<(), DatabaseError>
       where T::Key: Default { ... }
    fn import_dupsort<T: DupSort, R: DbTx>(
        &self,
        source_tx: &R,
    ) -> Result<(), DatabaseError> { ... }
}
Allows duplicating tables across databases

Provided Methods

fn import_table<T: Table, R: DbTx>( &self, source_tx: &R, ) -> Result<(), DatabaseError>

Imports all table data from another transaction.

fn import_table_with_range<T: Table, R: DbTx>( &self, source_tx: &R, from: Option<<T as Table>::Key>, to: <T as Table>::Key, ) -> Result<(), DatabaseError>
where T::Key: Default,

Imports table data from another transaction within a range.

This method works correctly with both regular and DupSort tables. For DupSort tables, all duplicate entries within the range are preserved during import.

fn import_dupsort<T: DupSort, R: DbTx>( &self, source_tx: &R, ) -> Result<(), DatabaseError>

Imports all dupsort data from another transaction.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors